@@ -193,7 +193,7 @@
 
   if (!fs::file_exists(news_path)) return(invisible())
 
-  orig_news <- readLines(news_path, warn = FALSE)
+  orig_news <- .readlines(news_path)
   orig_news <- paste(orig_news, collapse = "\n")
   new_news <- orig_news
 
